@@ -443,16 +443,8 @@ void regionselection::HandleMiddle()
 {
   QColor color, arrow;
   
-  if ( isFrameLocked() )
-  {
-    color = Qt::red;
-    arrow = Qt::red;
-  }
-  else
-  {
-    color = Qt::green;
-    arrow = Qt::black;
-  }
+  color = Qt::green;
+  arrow = Qt::black;
 
   QBrush brush( color, Qt::SolidPattern );
   painter->setBrush( brush );
@@ -569,6 +561,7 @@ void regionselection::paintEvent( QPaintEvent *event )
 {
   (void)event;
   painter->begin( this );
+  painter->setRenderHints( QPainter::Antialiasing, true );
 
   // Maskiert den Bereich für PrintSize und HandleMiddle
   if ( !isFrameLocked() )
@@ -598,8 +591,6 @@ void regionselection::paintEvent( QPaintEvent *event )
     setMask( r1 );
   }
 
-  //painter->begin( this );
-  painter->setRenderHints( QPainter::Antialiasing, true );
 
   HandleTopLeft();
   HandleTopMiddle();
@@ -609,8 +600,8 @@ void regionselection::paintEvent( QPaintEvent *event )
   HandleBottomMiddle();
   HandleBottomLeft();
   HandleLeftMiddle();
-  HandleMiddle();
-  printSize();
+  //HandleMiddle();
+  //printSize();
 
   // Blue Frame
   painter->setPen( QPen( Qt::blue, frameWidth ) );
@@ -637,7 +628,7 @@ void regionselection::paintEvent( QPaintEvent *event )
 void regionselection::lockFrame( bool status )
 {
     frameLocked = status;
-    qDebug() << "[vokoscreen][Regional selection] Frame locked:" << status;
+    qDebug() << "[vokoscreen] [Regional selection] Frame locked:" << status;
     qDebug();
     handlingFrameLock();
 }
