@@ -20,41 +20,29 @@ using namespace std;
 
 screencast::screencast()
 {
-    QSettings versionSettings(":/VERSION", QSettings::IniFormat );
-    versionSettings.beginGroup("Info");
-      bool beta = versionSettings.value( "Beta" ).toBool();
-      QString Beta;
-      if ( beta )
-        Beta = " Beta"; 
-      else
-        Beta = "";
-      
-      ProgName = versionSettings.value( "Progname" ).toString();
-      Version = versionSettings.value( "Version" ).toString() + Beta;
-    versionSettings.endGroup();
-
+    vkSettings.readAll();
+ 
     homepage = "<a href='http://www.kohaupt-online.de/hp'>" + tr( "Homepage" ) + "</a>";
     
     QString mailingliste = "<a href ='mailto:vokoscreen@googlegroups.com?subject=vokoscreen ";
-    mailingliste = mailingliste.append( Version ).append( "'" ).append( ">" + tr( "Mailinglist" ) + "</a>" );
+    mailingliste = mailingliste.append( vkSettings.getVersion() ).append( "'" ).append( ">" + tr( "Mailinglist" ) + "</a>" );
     
     email = "<a href ='mailto:tux@kohaupt-online.de?subject=vokoscreen ";
-    email = email.append( Version ).append( "'" ).append( ">" + tr( "Support" ) + "</a>" );
+    email = email.append( vkSettings.getVersion() ).append( "'" ).append( ">" + tr( "Support" ) + "</a>" );
 
     QString emaildeveloper = "<a href ='mailto:vkohaupt@freenet.de?subject=vokoscreen ";
-    emaildeveloper = emaildeveloper.append( Version ).append( "'" ).append( ">" + tr( "Developer" ) + "</a>" );
+    emaildeveloper = emaildeveloper.append( vkSettings.getVersion() ).append( "'" ).append( ">" + tr( "Developer" ) + "</a>" );
     
-    screencast::setWindowTitle( ProgName + " " + Version );
+    screencast::setWindowTitle( vkSettings.getProgName() + " " + vkSettings.getVersion() );
 
     QIcon icon;
     icon.addFile( QString::fromUtf8( ":/pictures/vokoscreen.png" ), QSize(), QIcon::Normal, QIcon::Off );
     screencast::setWindowIcon( icon );    
 
-    qDebug() << "[vokoscreen]" << "Version:" << Version;
+    qDebug() << "[vokoscreen]" << "Version:" << vkSettings.getVersion();
     qDebug() << "[vokoscreen]" << "Qt Version: " << qVersion();
     QvkAlsaDevice inBox ;
     qDebug() << "[vokoscreen]" << "asoundlib Version:" << inBox.getAlsaVersion();
-    //qDebug() << "[vokoscreen]" << "ffmpeg Version:" << getFfmpegVersion();
     qDebug();
     
     searchExternalPrograms();
@@ -68,14 +56,14 @@ screencast::screencast()
 
     tabWidget = new QTabWidget( centralWidget );
     tabWidget->setGeometry( 120, 0, 450, 190 );
-    tabWidget->setIconSize( QSize( 40, 40 ) );
+    tabWidget->setIconSize( QSize( 32, 32 ) );
 
     // Tab 1 Screen options ***************************************************
     QFrame *frame = new QFrame( this );
     frame->setGeometry( 120, 10, 300, 200 );
     frame->show();
     tabWidget->addTab( frame, "" );
-    tabWidget->setTabIcon( 0, QIcon( ":/pictures/monitor.png" ) );
+    tabWidget->setTabIcon( 0, QIcon::fromTheme( "video-display", QIcon( ":/pictures/monitor.png" ) ) );
     QFont qfont = frame->font();
     qfont.setPixelSize( 12 );
     frame->setFont( qfont );
@@ -124,12 +112,32 @@ screencast::screencast()
     CountdownSpinBox->setValue( 0 );
     CountdownSpinBox->show();
     
+    
+    // http://doc-snapshot.qt-project.org/4.8/qdesktopwidget.html#availableGeometry
+    QComboBox *ScreenComboBox = new QComboBox( frame );
+    ScreenComboBox->setGeometry( 160, 65, 200, 21 );
+    ScreenComboBox->hide();
+    QDesktopWidget *desk = QApplication::desktop();
+    qDebug() << "[vokoscreen]" << "---Begin search Screen---";
+    qDebug() << "[vokoscreen]" << "Number of screens:" << desk->screenCount();
+    for ( int i = 0; i < desk->screenCount(); i++ )
+    {
+      QString ScreenGeometryX = QString::number( desk->screenGeometry( i + 1 ).width() );
+      QString ScreenGeometryY = QString::number( desk->screenGeometry( i + 1 ).height() );      
+      ScreenComboBox->addItem( "Display " + QString::number( i ) + "   " + ScreenGeometryX + " x " + ScreenGeometryY, i );      
+      qDebug() << "[vokoscreen]" << "Display " + QString::number( i ) + "   " + ScreenGeometryX + " x " + ScreenGeometryY ;
+    }
+    qDebug() << "[vokoscreen]" << "---End search Screen---";
+    qDebug();
+    
+    
+    
     // Tab 2 Audio options ****************************************
     TabWidgetAudioFrame = new QFrame( this );
     TabWidgetAudioFrame->setGeometry( 120, 0, 300, 290 );
     TabWidgetAudioFrame->show();
     tabWidget->addTab( TabWidgetAudioFrame, "" );
-    tabWidget->setTabIcon( 1, QIcon( ":/pictures/micro.png" ) );
+    tabWidget->setTabIcon( 1, QIcon::fromTheme( "audio-input-microphone", QIcon( ":/pictures/micro.png" ) ) );
     qfont = TabWidgetAudioFrame->font();
     qfont.setPixelSize( 12 );
     TabWidgetAudioFrame->setFont( qfont );
@@ -163,7 +171,8 @@ screencast::screencast()
     TabWidgetVideoOptionFrame->setGeometry( 120, 0, 300, 200 );
     TabWidgetVideoOptionFrame->show();
     tabWidget->addTab( TabWidgetVideoOptionFrame, "" );
-    tabWidget->setTabIcon( 2, QIcon( ":/pictures/videooptionen.png" ) );
+    tabWidget->setTabIcon( 2, QIcon::fromTheme( "applications-multimedia", QIcon( ":/pictures/videooptionen.png" ) ) );
+
     qfont = TabWidgetVideoOptionFrame->font();
     qfont.setPixelSize( 12 );
     TabWidgetVideoOptionFrame->setFont( qfont );
@@ -177,7 +186,7 @@ screencast::screencast()
     FrameSpinBox = new QSpinBox( TabWidgetVideoOptionFrame );
     FrameSpinBox->setGeometry( QRect( 80, 10, 50, 25 ) );
     FrameSpinBox->setMinimum( 1 );
-    FrameSpinBox->setMaximum( 99 );
+    FrameSpinBox->setMaximum( 200 );
     FrameSpinBox->setSingleStep( 1 );
     FrameSpinBox->setValue( 25 );
     FrameSpinBox->show();
@@ -190,24 +199,24 @@ screencast::screencast()
     connect( FrameStandardButton, SIGNAL( clicked() ), SLOT( setFrameStandardSpinbox() ) );
 
     QLabel *VideocodecOptionLabel = new QLabel( TabWidgetVideoOptionFrame );
-    VideocodecOptionLabel->setGeometry( 20, 40, 50, 25 );
-    VideocodecOptionLabel->setText( tr( "Codec" ) );
+    VideocodecOptionLabel->setGeometry( 20, 40, 80, 25 );
+    VideocodecOptionLabel->setText( tr( "Videocodec" ) );
     VideocodecOptionLabel->show();
 
     VideocodecComboBox = new QComboBox( TabWidgetVideoOptionFrame );
-    VideocodecComboBox->setGeometry( 80, 40, 80, 25 );
+    VideocodecComboBox->setGeometry( 100, 40, 100, 25 );
     VideocodecComboBox->show();
     VideocodecComboBox->addItem( "mpeg4" );
     VideocodecComboBox->addItem( "libx264" );
     connect( VideocodecComboBox, SIGNAL( currentIndexChanged( int ) ), SLOT( currentIndexChangedCodec( int ) ) );
     
     QLabel *VideoContainerLabel = new QLabel(TabWidgetVideoOptionFrame );
-    VideoContainerLabel->setGeometry( 175, 40, 50, 25 );
+    VideoContainerLabel->setGeometry( 210, 40, 50, 25 );
     VideoContainerLabel->setText( tr( "Format" ) );
     VideoContainerLabel->show();
     
     VideoContainerComboBox = new QComboBox( TabWidgetVideoOptionFrame );
-    VideoContainerComboBox->setGeometry( 230, 40, 70, 25 );
+    VideoContainerComboBox->setGeometry( 260, 40, 70, 25 );
     VideoContainerComboBox->addItem( "avi" );
     VideoContainerComboBox->addItem( "mkv" );
     VideoContainerComboBox->show();
@@ -219,8 +228,26 @@ screencast::screencast()
     VideocodecStandardButton->show();
     connect( VideocodecStandardButton, SIGNAL( clicked() ), SLOT( setVideocodecStandardComboBox() ) );
     
+    QLabel *AudiocodecLabel = new QLabel( TabWidgetVideoOptionFrame );
+    AudiocodecLabel->setGeometry( 20, 70, 80, 25 );
+    AudiocodecLabel->setText( tr( "Audiocodec" ) );
+    AudiocodecLabel->show();
+    
+    AudiocodecComboBox = new QComboBox( TabWidgetVideoOptionFrame );
+    AudiocodecComboBox->setGeometry( 100, 70, 100, 25 );
+    AudiocodecComboBox->show();
+    AudiocodecComboBox->addItem( "libmp3lame" );
+    AudiocodecComboBox->addItem( "libvorbis" );
+    
+    QPushButton *AudiocodecStandardButton = new QPushButton( TabWidgetVideoOptionFrame );
+    AudiocodecStandardButton->setText( tr( "Default" ) );
+    AudiocodecStandardButton->setGeometry( 360, 70, 70, 25 );
+    AudiocodecStandardButton->show();
+    connect( AudiocodecStandardButton, SIGNAL( clicked() ), SLOT( setAudiocodecStandardComboBox() ) );
+    
+    
     HideMouseCheckbox = new QCheckBox( TabWidgetVideoOptionFrame );
-    HideMouseCheckbox->setGeometry( 20, 70, 300, 25 );
+    HideMouseCheckbox->setGeometry( 20, 100, 300, 25 );
     HideMouseCheckbox->setText( tr( "Do not record mouse cursor" ) );
     HideMouseCheckbox->show();
 
@@ -229,7 +256,7 @@ screencast::screencast()
     TabWidgetMiscellaneousFrame->setGeometry( 120, 0, 300, 200 );
     TabWidgetMiscellaneousFrame->show();
     tabWidget->addTab(TabWidgetMiscellaneousFrame, "" );
-    tabWidget->setTabIcon( 3, QIcon( ":/pictures/tools.png" ) );
+    tabWidget->setTabIcon( 3, QIcon::fromTheme( "preferences-system", QIcon( ":/pictures/tools.png" ) ) );
     qfont = TabWidgetMiscellaneousFrame->font();
     qfont.setPixelSize( 12 );
     TabWidgetMiscellaneousFrame->setFont( qfont );
@@ -275,7 +302,7 @@ screencast::screencast()
     QFrame *TabWidgetAboutFrame = new QFrame(this);
     TabWidgetAboutFrame->show();
     tabWidget->addTab( TabWidgetAboutFrame, "" );
-    tabWidget->setTabIcon( 4, QIcon( ":/pictures/about.png" ) );
+    tabWidget->setTabIcon( 4, QIcon::fromTheme( "dialog-information", QIcon( ":/pictures/about.png" ) ) );
     tabWidget->show();
     qfont = TabWidgetAboutFrame->font();
     qfont.setPixelSize( 12 );
@@ -423,7 +450,8 @@ screencast::screencast()
       sendPushButton->setEnabled( true );
     else
       sendPushButton->setEnabled( false );
-    
+
+  #ifndef NO_NEW_VERSION_CHECK
     QTimer::singleShot( 15000, &version, SLOT( doDownload() ) );
     connect( &version, SIGNAL( versionDownloadFinish() ), SLOT( buttonVersion() ) );
     updateButton = new QPushButton( centralWidget );
@@ -433,10 +461,12 @@ screencast::screencast()
     updateButton->setToolTip( tr( "New version available" ) );
     updateButton->hide();
     connect( updateButton, SIGNAL( clicked() ), SLOT( showHomepage() ) );  
+  #endif
     
     QLabel* label = new QLabel( centralWidget );
     label->setText("");
-    label->setGeometry( QRect( 0, 0, 123, 240) );
+    //label->setGeometry( QRect( 0, 0, 123, 240) );
+    label->setGeometry( QRect( 10, 0, 100, 190 ) );
     label->setAlignment( Qt::AlignCenter );
     label->show();
     QImage* qImage = new QImage( ":/pictures/VokoCola.png" );
@@ -526,7 +556,9 @@ screencast::screencast()
                                             << "smplayer"
                                             << "smplayer2"
                                             << "dragon"
-                                            << "banshee";
+                                            << "banshee"
+					    << "openshot"
+					    << "kdenlive";
     playerList.sort();
     QString playerName;
     QString resultString( qgetenv( "PATH" ) );
@@ -540,70 +572,59 @@ screencast::screencast()
          if ( QFile::exists( playerName ) )
          {
            qDebug() << "[vokoscreen]" << "Find Videoplayer :" << playerName;
-           VideoplayerComboBox->addItem( playerList.at( x ), playerName );
+	   QFileInfo playProg( playerName );
+	   if ( playProg.fileName() == "kdenlive" )
+	     playerName = playerName + " -i";
+
+	   VideoplayerComboBox->addItem( playerList.at( x ), playerName );
            break;
          }
        }
      }
      
-     qDebug() << "[vokoscreen]" << "---End search Videoplayer---";
-     qDebug();
+    qDebug() << "[vokoscreen]" << "---End search Videoplayer---";
+    qDebug();
 
-    // Einstellungen aus .conf einlesen
-    QSettings settings( ProgName, ProgName );
+      AudioOnOffCheckbox->setCheckState( Qt::CheckState( vkSettings.getAudioOnOff() ) );
 
-    // Dient nur zum anlegen des Profils damit ffmpeglog erstellt werden kann
-    settings.beginGroup("vokoscreen");
-      settings.setValue("Version", Version);
-    settings.endGroup();
+      AlsaRadioButton->setChecked( vkSettings.getAlsaSelect() );
 
-    settings.beginGroup( "Audio" );
-      AudioOnOffCheckbox->setCheckState( Qt::CheckState( settings.value( "AudioOnOff", 2 ).toUInt() ) );
-    settings.endGroup();
+      PulseDeviceRadioButton->setChecked( vkSettings.getPulseSelect() );
 
-    settings.beginGroup("Alsa" );
-      AlsaRadioButton->setChecked( settings.value( "Alsa", false ).toBool() );
-    settings.endGroup();
+      FullScreenRadioButton->setChecked( vkSettings.getFullScreenSelect() );
+      
+      WindowRadioButton->setChecked( vkSettings.getWindowSelect() );
+      
+      AreaRadioButton->setChecked( vkSettings.getAreaSelect() );
 
-    settings.beginGroup("Pulse");
-      PulseDeviceRadioButton->setChecked( settings.value( "Pulse", true ).toBool() );
-    settings.endGroup();
-
-    settings.beginGroup("Record");
-      FullScreenRadioButton->setChecked( settings.value( "FullScreen", true ).toBool() );
-      WindowRadioButton->setChecked( settings.value( "Window", false ).toBool() );
-      AreaRadioButton->setChecked( settings.value( "Area", false ).toBool() );
-    settings.endGroup();
-
-    settings.beginGroup( "Miscellaneous" );
       QDir Dir;
-      if ( Dir.exists( settings.value( "VideoPath", PathMoviesLocation() ).toString() ) )
-        SaveVideoPathLineEdit->setText( settings.value( "VideoPath", PathMoviesLocation() ).toString() );
+      if ( Dir.exists( vkSettings.getVideoPath() ) )
+        SaveVideoPathLineEdit->setText( vkSettings.getVideoPath() );
       else
-	PathMoviesLocation();
+        PathMoviesLocation();
 
-      int x = VideoplayerComboBox->findText( settings.value( "Videoplayer" ).toString(),Qt::MatchExactly );
+      int x = VideoplayerComboBox->findText( vkSettings.getVideoPlayer(), Qt::MatchExactly );
       if ( x == -1 )
         VideoplayerComboBox->setCurrentIndex( 0 );
       else
         VideoplayerComboBox->setCurrentIndex( x );
       
-      MinimizedCheckBox->setCheckState( Qt::CheckState( settings.value( "Minimized", 0 ).toUInt() ) );
+      MinimizedCheckBox->setCheckState( Qt::CheckState( vkSettings.getMinimized() ) );
       
-      CountdownSpinBox->setValue(  settings.value( "Countdown", 0 ).toUInt() );
-    settings.endGroup();
-    
-    settings.beginGroup( "Videooptions" );
-      FrameSpinBox->setValue( settings.value( "Frames", 25 ).toInt() );
-      VideocodecComboBox->setCurrentIndex( VideocodecComboBox->findText( settings.value( "Videocodec", "mpeg4" ).toString() ) );
-      VideoContainerComboBox->setCurrentIndex( VideoContainerComboBox->findText( settings.value( "Format", "mkv" ).toString() ) );
-      HideMouseCheckbox->setCheckState( Qt::CheckState( settings.value( "HideMouse").toUInt() ) );
-    settings.endGroup();
+      CountdownSpinBox->setValue( vkSettings.getCountdown() );
+      
+      FrameSpinBox->setValue( vkSettings.getFrames() );
 
-    settings.beginGroup( "GUI" );
-      setGeometry( settings.value( "X", "100" ).toUInt(), settings.value( "Y", "100" ).toUInt(), width(), height() );
-      tabWidget->setCurrentIndex ( settings.value( "Tab", "0" ).toUInt() );
-    settings.endGroup();
+      VideocodecComboBox->setCurrentIndex( VideocodecComboBox->findText( vkSettings.getVideoCodec() ) );
+      
+      AudiocodecComboBox->setCurrentIndex( AudiocodecComboBox->findText( vkSettings.getAudioCodec() ) );
+
+      VideoContainerComboBox->setCurrentIndex( VideoContainerComboBox->findText( vkSettings.getVideoContainer() ) );
+
+      HideMouseCheckbox->setCheckState( Qt::CheckState( vkSettings.getHideMouse()) );
+      
+      setGeometry( vkSettings.getX(), vkSettings.getY(), width(), height() );
+      tabWidget->setCurrentIndex( vkSettings.getTab() );
     
     // Statusbar
     stateChangedAudio( AudioOnOffCheckbox->checkState() );
@@ -627,15 +648,13 @@ screencast::screencast()
     connect( AreaRadioButton,       SIGNAL( clicked() ), SLOT( AreaOnOff() ) );
     connect( FullScreenRadioButton, SIGNAL( clicked() ), SLOT( AreaOnOff() ) );
     connect( WindowRadioButton,     SIGNAL( clicked() ), SLOT( AreaOnOff() ) );
-    settings.beginGroup( "Area" );
        myregionselection = new regionselection();
-       myregionselection->setGeometry ( settings.value( "X", 200 ).toUInt(),
-       				        settings.value( "Y", 200 ).toUInt(),
-				        settings.value( "Width", 200 ).toUInt() + myregionselection->borderLeft + myregionselection->borderRight + myregionselection->frameWidth,
-				        settings.value( "Height", 200 ).toUInt() + myregionselection->borderTop + myregionselection->borderBottom + myregionselection->frameWidth
+       myregionselection->setGeometry ( vkSettings.getAreaX(),
+       				        vkSettings.getAreaY(),
+				        vkSettings.getAreaWidth() + myregionselection->borderLeft + myregionselection->borderRight + myregionselection->frameWidth,
+				        vkSettings.getAreaHeight() + myregionselection->borderTop + myregionselection->borderBottom + myregionselection->frameWidth
 				      );
        myregionselection->close();
-    settings.endGroup();
     
     connect( MagnifierCheckBox, SIGNAL( clicked() ), SLOT( showMagnifier() ) );
     magnifier = new QvkMagnifier();
@@ -665,10 +684,8 @@ screencast::screencast()
    SystemTrayIconBlue = new QSystemTrayIcon( QIcon::fromTheme( "media-skip-forward", QIcon ( ":/pictures/go.png" ) ) );
    SystemTrayIconBlue->setToolTip( tr( "Go" ) );
 
-   settings.beginGroup( "GUI" );
-      SystrayCheckBox->setCheckState( Qt::CheckState( settings.value( "Systray", 2 ).toUInt() ) );
-      stateChangedSystray( Qt::CheckState( settings.value( "Systray", 2 ).toUInt() ) );
-   settings.endGroup();
+      SystrayCheckBox->setCheckState( Qt::CheckState( vkSettings.getSystray() ) );
+      stateChangedSystray( Qt::CheckState( vkSettings.getSystray() ) );
    
    connect( SystemTrayIconGreen,  SIGNAL( activated ( QSystemTrayIcon::ActivationReason ) ), this, SLOT( SystemTrayStart( QSystemTrayIcon::ActivationReason ) ) );
    connect( SystemTrayIconRed,    SIGNAL( activated ( QSystemTrayIcon::ActivationReason ) ), this, SLOT( SystemTrayStop( QSystemTrayIcon::ActivationReason ) ) );
@@ -710,16 +727,16 @@ screencast::~screencast()
 {
 }
 
-
+#ifndef NO_NEW_VERSION_CHECK
 void screencast::buttonVersion()
 {
-  QString localVersion = Version;
+  QString localVersion = vkSettings.getVersion();
   if ( version.isNewVersionAvailable( localVersion, version.getRemoteVersion() ) )
     updateButton->show();
   else
     updateButton->hide();
 }
-
+#endif
 
 void screencast::showHomepage()
 {
@@ -923,7 +940,7 @@ void screencast::AlsaWatcherEvent( QStringList CardxList )
     AlsaHwComboBox->addItem( AlsaDeviceList.at( i )->getAlsaName() , i );
   }
 
-  QSettings settings( ProgName, ProgName );
+  QSettings settings( vkSettings.getProgName(), vkSettings.getProgName() );
   settings.beginGroup( "Alsa" );
     int x = AlsaHwComboBox->findText( settings.value( "NameCaptureCard" ).toString(),Qt::MatchExactly );
     AlsaHwComboBox->setCurrentIndex( x );
@@ -967,12 +984,12 @@ void screencast::closeEvent( QCloseEvent * event )
 
 void screencast::saveSettings()
 {
-  QSettings settings( ProgName, ProgName );
+  QSettings settings( vkSettings.getProgName(), vkSettings.getProgName() );
   
   settings.clear();
 
   settings.beginGroup( "vokoscreen" );
-    settings.setValue( "Version", Version );
+    settings.setValue( "Version", vkSettings.getVersion() );
   settings.endGroup();
 
   settings.beginGroup( "Audio" );
@@ -1006,6 +1023,7 @@ void screencast::saveSettings()
   settings.beginGroup( "Videooptions" );
     settings.setValue( "Frames", FrameSpinBox->value() );
     settings.setValue( "Videocodec", VideocodecComboBox->currentText() );
+    settings.setValue( "Audiocodec", AudiocodecComboBox->currentText() );
     settings.setValue( "Format", VideoContainerComboBox->currentText() );
     settings.setValue( "HideMouse", HideMouseCheckbox->checkState() );    
   settings.endGroup();
@@ -1185,6 +1203,15 @@ void screencast::setVideocodecStandardComboBox()
 }
 
 
+/**
+ * Set standard Audio codec
+ */
+void screencast::setAudiocodecStandardComboBox()
+{
+  AudiocodecComboBox ->setCurrentIndex( AudiocodecComboBox->findText( "libmp3lame", Qt::MatchExactly )  );
+}
+
+
 /**
  * Set standard fps
  */
@@ -1212,7 +1239,7 @@ void screencast::makeAsoundrc()
     qDebug() << "[vokoscreen] File not found .asound for PulseAudio Plugin";
     qDebug() << "[vokoscreen] Create file .asound for PulseAudio Plugin";
     QTextStream out( &qFile );
-    out << "# create by vokoscreen " << Version << "\n";
+    out << "# create by vokoscreen " << vkSettings.getVersion() << "\n";
     out << "\n";
     out << "pcm.pulse {\n";
     out << "  type pulse\n";
@@ -1261,36 +1288,6 @@ void screencast::readyReadStandardError()
     statusBarLabelFps->setText( output.mid( x + 4, 3 ).replace( " ", "" ) );
   }
 
-  // 
-  int fps = statusBarLabelFps->text().toUInt();
-  if ( fps >=  FrameSpinBox->value() )
-  {
-    statusBarLabelFps->setToolTip( tr( "Actual frames per second" ) );
-    statusBarLabelFps->setAutoFillBackground( true );
-    QPalette pal( statusBarLabelFps->palette() );
-    pal.setColor( QPalette::Foreground, Qt::black );
-    pal.setColor( QPalette::Background, Qt::green );
-    statusBarLabelFps->setPalette( pal );
-  }
-
-  if ( fps < FrameSpinBox->value() )
-  {
-    statusBarLabelFps->setToolTip( tr( "Your Actual frames in the Settings is too heigh" ) );
-    statusBarLabelFps->setAutoFillBackground( true );
-    QPalette pal( statusBarLabelFps->palette() );
-    if ( pal.color( QPalette::Background ) == Qt::red )
-    {
-      pal.setColor( QPalette::Foreground, Qt::black );
-      pal.setColor( QPalette::Background, Qt::yellow );
-    }
-    else
-    {
-      pal.setColor( QPalette::Foreground, Qt::black );
-      pal.setColor( QPalette::Background, Qt::red );
-    }
-    statusBarLabelFps->setPalette( pal );
-  }    
-  
   QFileInfo fileInfo( PathTempLocation() + QDir::separator() + nameInMoviesLocation );
   statusBarLabelSize->setText( QString::number( fileInfo.size() / 1024 ) );
 }
@@ -1423,21 +1420,20 @@ void screencast::stateChanged ( QProcess::ProcessState newState )
       }
     }
        
-    if (newState == QProcess::Running)
+    if ( newState == QProcess::Running )
     {
       qDebug();
-      qDebug() << "[vokoscreen] ffmpeg is running and is ready for reading and writing";
+      qDebug() << "[vokoscreen]" << recordApplikation << "is running and is ready for reading and writing";
     }
    
-    if (newState == QProcess::NotRunning)
+    if ( newState == QProcess::NotRunning )
     {
       qDebug();
-      qDebug() << "[vokoscreen] ffmpeg is not running";
+      qDebug() << "[vokoscreen]" << recordApplikation << "is not running";
 
       //Enables the customarea rectangle again. (Is diabled in record() )
-        if(!PauseButton->isChecked()){
-            myregionselection->lockFrame(false);
-        }
+      if ( !PauseButton->isChecked() )
+         myregionselection->lockFrame( false );
     }
 }
 
@@ -1448,7 +1444,7 @@ void screencast::error( QProcess::ProcessError error )
   if ( error == QProcess::Crashed )
   {
     // remove crashed directory
-    QSettings settings1( ProgName, ProgName );
+    QSettings settings1( vkSettings.getProgName(), vkSettings.getProgName() );
     QFileInfo settingsPath1( settings1.fileName() );
     QFile file1( settingsPath1.absolutePath() );
     QString workDirectory1 = file1.fileName();
@@ -1462,7 +1458,7 @@ void screencast::error( QProcess::ProcessError error )
     }
     
     // Move ffmpeg.log, vokoscreen.log, vokoscreen.conf in directory crashed
-    QSettings settings( ProgName, ProgName );
+    QSettings settings( vkSettings.getProgName(), vkSettings.getProgName() );
     QFileInfo settingsPath( settings.fileName() );
     QFile file( settingsPath.absolutePath() );
     QString workDirectory = file.fileName();
@@ -1568,7 +1564,7 @@ void screencast::Pause()
 	PauseButton->click();
         return;
       }
-      
+      Countdown();
       shortcutStop->setEnabled( true );
       PauseButton->setText( tr( "Pause" ) );
       startRecord( PathTempLocation() + QDir::separator() + PauseNameInTmpLocation() );
@@ -1602,6 +1598,7 @@ void screencast::Pause()
 	PauseButton->click();
         return;
       }
+      Countdown();
       shortcutStop->setEnabled( true );
       PauseButton->setText( tr( "Pause" ) );
       startRecord( PathTempLocation() + QDir::separator() + PauseNameInTmpLocation() );
@@ -1629,12 +1626,12 @@ void screencast::play()
   QStringList List = Dira.entryList( filters, QDir::Files, QDir::Time );
   if ( List.isEmpty() )
   {
-    QProcess *SystemCall = new QProcess( this );
+    QProcess *SystemCall = new QProcess();
     SystemCall->start( player );
   }
   else
   {
-    QProcess *SystemCall = new QProcess( this );
+    QProcess *SystemCall = new QProcess();
     SystemCall->start( player + " " + PathMoviesLocation() + QDir::separator() + List.at( 0 ) );
   }
 }
@@ -1725,7 +1722,7 @@ void screencast::windowMove()
     return;
   } 
   // End Window is closed
-  
+
   // Wenn Versatzwert kleiner null ist
   QString x = QString::number( QxtWindowSystem::windowGeometry( moveWindowID ).x() );
   int xx = x.toInt();
@@ -1736,7 +1733,7 @@ void screencast::windowMove()
   int yy = y.toInt();
   if ( yy < 0 )
     y = "0";
-  
+
   if ( ( deltaXMove != x ) or ( deltaYMove != y ) )
     if ( SystemCall->state() == QProcess::Running ) 
       moveWindowPause();
@@ -1937,14 +1934,16 @@ void screencast::AudioOnOff()
       AlsaHwComboBox->setEnabled( true );
     else
       AlsaHwComboBox->setEnabled( false );
+    
+    AudiocodecComboBox->setEnabled( true );
   }
   else
   {
     AlsaRadioButton->setEnabled( false );
     AlsaHwComboBox->setEnabled( false );
-//    PulseRadioButton->setEnabled( false );
     Pulseframe->setEnabled( false );
     PulseDeviceRadioButton->setEnabled( false );
+    AudiocodecComboBox->setEnabled( false );
   }
 }
 
@@ -2006,7 +2005,7 @@ QString screencast::PathMoviesLocation()
   {
     if ( QDesktopServices::storageLocation( QDesktopServices::MoviesLocation).isEmpty() )
     {
-       Path = QDesktopServices::storageLocation( QDesktopServices:: QDesktopServices::HomeLocation );
+       Path = QDesktopServices::storageLocation( QDesktopServices::HomeLocation );
        SaveVideoPathLineEdit->setText(Path);
     }
     else
@@ -2022,7 +2021,7 @@ QString screencast::PathMoviesLocation()
 QString screencast::PathTempLocation()
 {
   // Doppelter ProgName um Eindeutigkeit in tmp zuerreichen
-  QString tmpName = ProgName + "-" + ProgName;
+  QString tmpName = vkSettings.getProgName() + "-" + vkSettings.getProgName();
   QString tempPathProg = QDesktopServices::storageLocation ( QDesktopServices::TempLocation ) + QDir::separator() + tmpName;
   QDir dirTempPathProg( tempPathProg );
   if ( not dirTempPathProg.exists() )
@@ -2246,12 +2245,11 @@ QString screencast::myAcodec()
 {
   QString acodec;
   if ( ( AudioOnOffCheckbox->checkState() == Qt::Checked ) and ( AlsaRadioButton->isChecked() ) and ( AlsaHwComboBox->currentText() > "" ) )
-     return " -acodec libmp3lame";
-
+     return "-c:a " + AudiocodecComboBox->currentText(); //"-c:a libmp3lame";
   
   if ( ( AudioOnOffCheckbox->checkState() == Qt::Checked ) and ( PulseDeviceRadioButton->isChecked() ) and ( myPulseDevice() > "" ) )
-     return " -acodec libmp3lame";
- 
+     return "-c:a " + AudiocodecComboBox->currentText(); //"-c:a libmp3lame";
+
   return "";
 }
 
@@ -2458,7 +2456,7 @@ void screencast::record()
   }
 
   // set working directory for writing and delete the ffmpegLog from Profil directory
-  QSettings settings( ProgName, ProgName );
+  QSettings settings( vkSettings.getProgName(), vkSettings.getProgName() );
   QFileInfo settingsPath( settings.fileName() );
   QFile file( settingsPath.absolutePath() );
   QString workDirectory = file.fileName();
@@ -2482,8 +2480,8 @@ void screencast::record()
      dir.remove( PathTempLocation().append(QDir::separator() ).append(stringList.at( i ) ) );
 
   // frame rate
-  QString frame = "-r " + QString().number( FrameSpinBox->value() );
-  
+  //QString frame = "-r " + QString().number( FrameSpinBox->value() );
+  QString framerate = "-framerate " + QString().number( FrameSpinBox->value() );
   // Videocodec
   QString myVcodec = VideocodecComboBox->currentText();
   if ( myVcodec == "libx264" )
@@ -2513,38 +2511,29 @@ void screencast::record()
     quality = " -qscale 1 ";
 
   clickedRecordButtonScreenSize();
-  
+
   ffmpegString = recordApplikation + " "
-               + myReport
-               + myAlsa()
-	       + "-f x11grab "
-               + frame
-	       + " -s "
-	       + getRecordWidth()
-	       + "x"
-	       + getRecordHeight()
-	       + " -i :0.0+"
-	       + deltaX + "," 
-	       + deltaY
-               + noMouse()
-	       + " -pix_fmt yuv420p" // Neu das funktioniert sehr gut, ohne ca. 80 fps, mit 99fps bei eingestellten 99fps und preset medium aber nur unter opensuse, unter Ubuntu 13.04 keine Veränderung
-	       + " -vcodec "
-	       + myVcodec
-       	       + myAcodec()
-	       //+ " -ab 256k "  //********************************************Neu
-      	       //+ " -ar 48000 "  //********************************************Neu
-      	       + " -ar " + mySample()
-	       + quality
-	       + frame + " ";
-	       	            
+               + myReport + " "
+               + "-f x11grab" + " "
+               + framerate + " "
+               + "-video_size" + " " + getRecordWidth() + "x" + getRecordHeight() + " "
+               + "-i :0.0+" + deltaX + "," + deltaY
+               + noMouse() + " "
+               + "-dcodec copy" + " "
+               + myAlsa() + " "
+               + "-pix_fmt yuv420p" + " "
+               + "-c:v" + " " + myVcodec + " "
+               + myAcodec() + " "
+               + quality + " ";
+  
   startRecord( PathTempLocation() + QDir::separator() + nameInMoviesLocation );
   
-  QFile FileVokoscreenLog(settingsPath.absolutePath() + QDir::separator() + ProgName + ".log");
+  QFile FileVokoscreenLog(settingsPath.absolutePath() + QDir::separator() + vkSettings.getProgName() + ".log");
   if ( !FileVokoscreenLog.open( QIODevice::WriteOnly ) ) 
     qDebug() << "Datei konnte nicht angelegt werden: " << FileVokoscreenLog.errorString();
   
   QTextStream stream( &FileVokoscreenLog );
-  stream << ProgName << " Version: " << Version << "\n";
+  stream << vkSettings.getProgName() << " Version: " << vkSettings.getVersion() << "\n";
   stream << "Record resolution: " << getRecordWidth() << "x" << getRecordHeight() << "\n";
   stream << "Alsa string: " << myAlsa() << "\n";
   stream << "Qt Version: " << qVersion() << "\n";
@@ -2559,7 +2548,7 @@ void screencast::record()
 
 void screencast::startRecord( QString RecordPathName )
 {
-  qDebug() << "[vokoscreen]"<< "ffmpegcommand :" << ffmpegString + RecordPathName;
+  qDebug() << "[vokoscreen]"<< "Executive command :" << ffmpegString + RecordPathName;
 
   if ( PulseDeviceRadioButton->isChecked() )
   {
